Developer's Guide
=================

Module contents
---------------

.. automodule:: opticalglass
    :members:
    :undoc-members:
    :show-inheritance:

Submodules
----------

glass
+++++

.. automodule:: opticalglass.glass
    :members:
    :undoc-members:
    :show-inheritance:

glassfactory
++++++++++++

.. automodule:: opticalglass.glassfactory
    :members:
    :undoc-members:
    :show-inheritance:

buchdahl
++++++++

.. automodule:: opticalglass.buchdahl
    :members:
    :undoc-members:
    :show-inheritance:

spectral_lines
++++++++++++++

.. automodule:: opticalglass.spectral_lines
    :members:
    :undoc-members:
    :show-inheritance:

util
++++

.. automodule:: opticalglass.util
    :members:
    :undoc-members:
    :show-inheritance:

glasserror
++++++++++

.. automodule:: opticalglass.glasserror
    :members:
    :undoc-members:
    :show-inheritance:

GUI Submodules
--------------

glassmap
++++++++

.. automodule:: opticalglass.glassmap
    :members:
    :undoc-members:
    :show-inheritance:

glassmapviewer
++++++++++++++

.. automodule:: opticalglass.glassmapviewer
    :members:
    :undoc-members:
    :show-inheritance:

glasspolygons
+++++++++++++

.. automodule:: opticalglass.glasspolygons
    :members:
    :undoc-members:
    :show-inheritance:


Catalog-specific Submodules
---------------------------

cdgm
++++

.. automodule:: opticalglass.cdgm
    :members:
    :undoc-members:
    :show-inheritance:

hikari
++++++

.. automodule:: opticalglass.hikari
    :members:
    :undoc-members:
    :show-inheritance:

hoya
++++

.. automodule:: opticalglass.hoya
    :members:
    :undoc-members:
    :show-inheritance:

ohara
+++++

.. automodule:: opticalglass.ohara
    :members:
    :undoc-members:
    :show-inheritance:

schott
++++++

.. automodule:: opticalglass.schott
    :members:
    :undoc-members:
    :show-inheritance:

sumita
++++++

.. automodule:: opticalglass.sumita
    :members:
    :undoc-members:
    :show-inheritance:

